#!/bin/bash
#Description: const params
#Copyright: Copyright © Huawei Technologies Co., Ltd. 2020. All rights reserved.
#History: 2020-05-11 created

# 获取创建用户默认路径
function get_home_path()
{
	# 默认目录为/home # 用户自定义的用户家目录 默认为home
	useradd_file="/etc/default/useradd"
	if [ ! -f ${useradd_file} ]; then
		USER_HOME="/home"
		return
	fi
	# 当配置为空时，默认家目录为根目录
	if grep -E "^HOME=$" "${useradd_file}" >>/dev/null 2>&1; then
		USER_HOME="/"
		return
	fi
	# grep -v “#” 去除注释情况 '# HOME=/home' 和 'HOME=/home' 共存情况
	default_home=$(grep -E "HOME=" "${useradd_file}" | grep -v "#" | awk -F"=" '{print $2}')
	if [ -z "${default_home}" ]; then
		USER_HOME="/home"
	else
		USER_HOME="${default_home}"
	fi
}
get_home_path

# shell read设置超时时间300s
READ_TIMEOUT=300
DEVKIT_USER="devkit"
DEVKIT_HOME="${USER_HOME}/${DEVKIT_USER}"
CONFIG_FILE="${DEVKIT_HOME}/devkit_conf/install.ini"
SUCCESS=0
ERROR=1
DOING=2
ECHO=3
# 插件安装所需空间1G（server和agent相等）
INSTALL_SPACE_NEED=1000000
# 工具使用空间阈值8G
TOOL_USE_SPACE=8000000
PYTHON_CHILD_VERSION=3.9
PACKAGE_TOOLS_LIST=("yum" "apt" "zypper")

declare -A ESSENTIAL_LIB_LIST=()
declare -A ESSENTIAL_CMD_LIST=()
declare -A LIB_CHECK_LIST=()
declare -A NON_ESSENTIAL_LIB_LIST=(['yum']='rpmrebuild java-devel'
	['apt']='pkg-deb java-devel'
	['zypper']='rpmrebuild java-devel'
)

NON_ESSENTIAL_YUM_CMD_LIST=("rpmrebuild --version")
NON_ESSENTIAL_APT_CMD_LIST=("dpkg-deb --version" )

SUDO_FILE="/etc/sudoers.d/devkit_porting_sudoers"
CPU_ID_FILE="/sys/devices/system/cpu/cpu0/regs/identification/midr_el1"
KUNPENG920_ID="0x00000000481fd010"
KUNPENG920B_ID="0x00000000480fd020"
KUNPENG920C_ID="0x00000000480fd030"
KUNPENG920E_ID="0x00000000480fd450"
ORANGE_PI_ID="0x00000000001fd022"

SUPPORTED_ARM=("${KUNPENG920_ID}" "${KUNPENG920B_ID}" "${KUNPENG920C_ID}" "${KUNPENG920E_ID}" "${ORANGE_PI_ID}")
OS_TYPE_LIST=('OpenEulerOS' 'EulerOS' 'CentOS' 'NeoKylinOS' 'SLESOS' 'UbuntuOS' 'DebianOS' 'LinxOS' 'KylinSecOS' 'KylinOS' 'UOS' 'iSoftOS' 'BCLinuxOS' 'UnionTechOS' 'ctyunOS')
# 框架OS映射插件OS（RedHatOS不支持ARM）
declare -A OS_MAP=(["DeepinOS"]="DebianOS" ["uosEulerOS"]="EulerOS" )
declare -A COMMAND_LIST=(["OpenEulerOS"]="yum" ["EulerOS"]="yum" ["CentOS"]="yum" ["NeoKylinOS"]="yum" ["SLESOS"]="zypper" ["UbuntuOS"]="apt" ["DebianOS"]="apt" ["LinxOS"]="apt" ["KylinSecOS"]="yum" ["KylinOS"]="yum" ["UOS"]="apt" ["iSoftOS"]="yum" ["UnionTechOS"]="yum" ["BCLinuxOS"]="yum" ["ctyunOS"]="yum")
