#!/bin/bash
#Description: kill process
#Copyright: Copyright © Huawei Technologies Co., Ltd. 2020. All rights reserved.
#History: 2020-5-11 created
pid=$1
cmd=$@
error=1
d_process_mes="Fail to kill process."

function check_after_kill()
{
    local l_pid=$1
    local time_count=0
    while ((${time_count}<50))
    do
        sleep 0.01
        let time_count++
        local l_process_state=$(ps -o pid,state -ax | grep ${l_pid} | awk '$1=$1' | cut -d" " -f2)
        if [[ -z $l_process_state ]]; then
            return
        fi
    done
    echo "process ${l_pid} kill failed after 0.5s.Force to kill by signal 9."
    kill -9 $l_pid
}

function kill_process()
{
    local l_killpara=$1
    local l_pid=$2
    local l_reverse_flag=$3
    local process_state="D"
    local time_count=0
    while ((${time_count}<60))
    do
        process_state=$(ps -o pid,state -ax | grep ${l_pid} | awk '$1=$1' | cut -d" " -f2)
        if [[ -z $process_state ]]; then
            return
        elif [[ $process_state =~ "D" ]]; then
            let time_count++
            sleep 1
        else
            kill -$l_killpara $l_pid
            if [[ ${l_reverse_flag} -eq 5 ]]; then
                check_after_kill $l_pid
            fi
            return
        fi
    done
    echo " ${d_process_mes} Process status is ${process_state}.">&2
    return 1
}
echo "$cmd" | grep -q -E '^[ 0-9,]*$'
if [[ "$?" -ne 0 ]]
then
    echo "kill_process.sh : parameter error!">&2
    exit ${error}
fi
killpara=${2:-9}
kill_mode=${3:-0}
echo "${kill_mode}"
echo "${pid}"
# 不需要进程树处理，调用pstree 某些场景存在性能问题
if [ "${kill_mode}" -eq 6 ];then
    # 发送信号量给指定进程
    kill -$killpara ${pid}
    exit $?
fi
pid_line[0]=$pid
# 存在进程树中相关的进程/proc/PID不存在导致获取空树的场景，优化方式
pid_exist=$(ps -eo pid | grep -w $pid)
if [[ -z ${pid_exist} ]]; then
    echo "${pid} is not exist."
    exit 0
fi
if [ "${kill_mode}" -eq 4 ]; then
  #sysperformance,通过kill进程组方式
  pgroup=$(ps -p $pid -o pgrp | awk 'NR==2')
  for ((i = 1; i <= 10; i++)); do
    pids=$(ps -e -o pid,pgrp | awk -v awk_pgroup="$pgroup" '{if($2==awk_pgroup)  print $1}')
    if [ -n "$pids" ]; then
      for ((j=${#pids[@]}-1; j>=0;j--)); do
        kill -$killpara ${pids[$j]} 2>/dev/null
        sleep 0.02
      done
      sleep 0.5
    else
      break
    fi
  done
  exit 0
fi
for ((k=0; k<60; k++))
do
    pid_line=$(pstree -p -l ${pid})
    echo "pid_line=${pid_line}"
    pid_line1=$(echo $pid_line | awk 'BEGIN{ FS="(" ; RS=")" } NF>1 { print $NF }')
    echo "pid_line1=${pid_line1}"
    if [[ ! -z ${pid_line1} ]]; then
        break
    fi
    sleep 1
done
pid_line2=($pid_line1)
if [ "${kill_mode}" -eq 0 ];then
    for ((i=0;i<${#pid_line2[@]};i++))
    do
    {
        echo "----------"
        echo ${pid_line2[$i]}
        kill_process $killpara ${pid_line2[$i]} ${kill_mode}
        if [ $? -eq 1 ];then
            exit 1
        fi
        sleep 0.02
    }
    done
elif [ "${kill_mode}" -eq 2 ];then
    ###hpc任务专用，直接杀主进程，杀进程树无法生成otf2文件。
    kill_process $killpara ${pid_line2[1]} ${kill_mode}
elif [ "${kill_mode}" -eq 3 ];then
    #sysperformance,
    pstree -p -l ${pid}|awk 'BEGIN{ FS="(" ; RS=")" } NF>1 { print $NF }'|xargs kill -$killpara
    if [ $? -eq 1 ];then
        exit 1
    fi
    sleep 0.02
elif [ "${kill_mode}" -eq 1 ] || [ "${kill_mode}" -eq 5 ]; then
    for ((i=${#pid_line2[@]} - 1;i>=0;i--))
    do
    {
        echo "----------"
        echo ${pid_line2[$i]}
        kill_process $killpara ${pid_line2[$i]} ${kill_mode}
        if [ $? -eq 1 ];then
            exit 1
        fi
        sleep 0.1
    }
    done
else
    echo "kill_process.sh : parameter error!">&2
    exit ${error}
fi
exit $?